      subroutine hec_trig_evt
c
c process trigger bits from pattern units and produce useful
c trigger words to be found in hec_trig.inc
c
c thanks to Leonid Kourtchaninov
c
      implicit none
c
      integer i
      logical vm, m1, m2
c
c user datacard values common
c
      include'hec_datacard.inc' !datacard values
      include'hec_evth.inc'     !event header
      include'hec_runh.inc'     !run header 
      include'hec_trig.inc'     !event trigger
c
c define a halo trigger
c - hits in the veto wall before the calorimeter
c - hits on the up and down counters with a hole that are in front
c   of the f1 and f2 finger counters
c - early pileup hits
c - late pileup hits
c note the the hardware definition of the halo does not 
c included the late pileup lpat_4(1)
c L.K. agrees that the following definition is better
c
      vm = .false.
      do i = 5, 16
        vm = vm .or. lpat_2(i)
      enddo
      trig_halo = vm .or. lpat_1(2) .or. lpat_1(11)
      trig_halo = trig_halo .or. lpat_1(5) .or. lpat_4(1)
c
c define a muon counter trigger
c - hits from the muon counter wall after the cryostat
c - hits from the muon counter wall after the shielding
c before may97, lpat_3(1) was pi/e/mu
c from   may97, lpat_3(1) is m2/1.
c
      m1 = .false.
      do i = 1, 4
       m1 = m1 .or. lpat_2(i)
      enddo
      do i = 11, 16
       m1 = m1 .or. lpat_3(i)
      enddo
      m2 = .false.
      if (irunpd .le. 4) then
        do i = 2, 10
          m2 = m2 .or. lpat_3(i)
        enddo
      else
        do i = 1, 10
          m2 = m2 .or. lpat_3(i)
        enddo
      endif
      trig_mucounters = m1 .and. m2
c
c get the pretrigger
c before may97,          pretrigger is in lpat_1(14)
c from   may97 run 6503, pretrigger is in lpat_1(3)
c set it true otherwise...
c
      trig_pretrigger = .true.
      if (irunpd .le. 4) then
        trig_pretrigger = lpat_1(14)
      elseif (irunpd .ge. 5 .and. run_no .ge. 6503) then
        trig_pretrigger = lpat_1(3)
      endif
c
c define a minimum bias physics trigger
c - beam signal
c - pretrigger (both f1 and f2 fingers (and maybe b1))
c - no halo
c note that this corresponds to the e/pi/mu trigger bit,
c except that here late pileup (lpat_4(1)) are included
c in the definition of halo. 
c before may97, e/pi/mu is in lpat_3(1)
c from   may97 run 6503, e/pi/mu is in lpat_1(10)
c
      trig_physics = trig_pretrigger .and. (.not. trig_halo)
c
c define a muon trigger
c
      trig_mu = trig_physics .and. trig_mucounters
c
c define a electron/pion trigger
c
      trig_epi = trig_physics .and. (.not. trig_mucounters)
c
c define a pion trigger
c - uses the cerenkov counter info
c
      trig_pi = trig_epi .and. (.not. lpat_1(6))
c
c define an electron trigger
c
      trig_e = trig_epi .and. lpat_1(6)
c
c define a random trigger
c software random trigger, uncorrelated with particle
c before may97 run 6503, this is in lpat_4(3)
c from   may97 run 6503, this is in lpat_1(14)
c 
      if (irunpd .le. 5 .and. run_no .lt. 6503) then
        trig_random = lpat_4(3)
      else
        trig_random = lpat_1(14)
      endif
c
c hardware random trigger
c trigger set 20ms after some particle
c
      trig_random_hard = lpat_1(4)
c      
      end
