      subroutine hec_ntuple_ini
c
c routine to initialize column-wise ntuples for ntuple package
c
c               name        type  description
c run ntuple:
c               nt_runno     i    run number
c               nt_beamen    r    beam energy
c               nt_noevt     i    number of events
c               nt_parttyp   i    particle type
c               nt_cryox     r    cryostat position in x
c               nt_tabley    r    table position in y
c               nt_peakf     i    peak finding method used
c               nt_calibf    c    calibration file used
c               nt_runpd     i    run period
c               nt_nocell    i    number of cells used
c
c slow controls:
c               nt_lartmp    r    liquid argon temperature
c               nt_press     r    cryostat pressure
c               nt_time      r    time data was taken
c
c
c event ntuple:
c               nt_evntno    i    event number
c               nt_trig      i    trigger flag array 
c                                 (physics,electron,pion,muon,random)
c               nt_ic_index  i    list of channels kept for the event
c               nt_iz        i    z layer # of each channel
c               nt_adcmx     r    max adc value for each channel
c               nt_timmx     r    time of adc max for each channel
c               nt_ene       r    energy of each channel (nA)
c               nt_ped       r    pedestal for each channel
c               nt_ped_rms   r    pedestal r.m.s. for each channel
c               nt_chflag    i    channel flag (1=good, 0=bad)
c
        implicit none
c
c parameter and geometry commons
c
        include'hec_par.inc'      ! shared parameters
        include'hec_datacard.inc' ! datacard values
        include'hec_geo.inc'      ! geometry correspondance tables
        include'hec_ntuple.inc'   ! ntuple common
c
        integer istat
	character*512 tags1,tags2
c
c initialize list of column names for run header
c
	tags1 = 'nt_runno:i,nt_beamen:r,nt_noevt:i,nt_partyp:i,'//
     +          'nt_cryox:r,nt_tabley:r,'//
     +          'nt_peakf:i,nt_runpd:i,nt_nocell:i,'//
     +          'nt_calibf:c*8'
        tags2 = 'nt_lartmp:r,nt_press:r,nt_time:r'
c
c open hbook file for standard ntuple
c
	call hropen(io_ntp,'ntuple','ntuple.hbook','n',1024,istat)
	if (istat .ne. 0) then
	   print*, 'error opening ntuple file'
	   return
	endif
c
c initialize (book) ntuples (disk resident)
c
	call hbnt(100,'standard run ntuple','D')
	call hbnt(101,'standard slow control ntuple','D')
	call hbnt(102,'standard event ntuple','D')
c
c define columns for run header ntuple
c
	call hbname(100,'runtuple',nt_runno,tags1)
c
c define columns for slow control ntuple
c
	call hbname(101,'sctuple',nt_lartmp,tags2)
c
c define columns for event ntuple
c
	call hbname(102,'evttuple',nt_evntno,
     +              'nt_evntno:i,'                 //
     +              'nt_trig(5):i')
        call hbname(102,'evttuple',nt_cells_used,
     +              'nt_cells_used[0,200]:i,'  //
     +              'nt_ic_index(nt_cells_used):i,'//            
     +              'nt_iz(nt_cells_used):i,'  //            
     +              'nt_adcmx(nt_cells_used):r,'  //            
     +              'nt_timmx(nt_cells_used):r,'  //            
     +              'nt_ene(nt_cells_used):r,'  //            
     +              'nt_pedest(nt_cells_used):r,' //
     +              'nt_ped_rms(nt_cells_used):r,' //
     +              'nt_chflag(nt_cells_used):i')
c
        return 
        end
