      subroutine hec_online_interface
c
c provides online interface in "autorun" mode
c never called from regular hec_adc package
c
      implicit none
c
c online histogram common and parameter common
c This is shared with normal online running mode
c
      include'hec_par.inc'           ! shared parameters
      include'hec_his_sys.inc'       ! online histogram ids
c
c local variables
c
      integer maxcell
      parameter (maxcell=5)
      integer high_ic(maxcell),ic
      integer hisnum
      integer istat
c
      integer run_number
c
      integer hisorg
c
      character*5 chidh
      character*20 comment
      logical psbutton, zoombutton, zoomstatus
c
c access existing hbook file
c
      call hropen(35, 'hec_online', 
     +  'hec_online.hbook', ' ', 1024, istat)
      if (istat .ne. 0) then
        print *, '*** problem opening online hbook file ***',
     +  istat
        stop
      endif
c
c read histograms into memory
c
      call hcdir('//hec_online',' ')
      call hrin(0,0,0)
c
c initialize HPLOT graphical environment (for X11)
c
      call hplint(1)
c
c get list of 5 highest energy cells
c
      open(40,file="highcell.list",status="OLD")
      read(40, *) run_number
      read(40, '(5i3)') (high_ic(ic), ic = 1, 5)
      close(40)      
c
c start with a zone 1 2 noise plot
c
      call igmeta(0,0)
      call hplzon(1,2,1,' ')
      call hplot(2,' ',' ',0)
      call hplot(4,' ',' ',0)
      call iuwk(0,1)
      call igterm
c
c list histogram menu
c
      call hec_online_menu
c
c open user summary ps file
c
      open(unit=10,file='user_summary.ps',form='formatted',
     +status='unknown')
c
c while the user has not entered 0 as a histogram number
c
      hisnum = -1
      do while (hisnum .ne. 0)
c
c choose zone 1 1 for plot
c
        call hplzon(1,1,1,' ')
c
c prompt user for histogram number and read from keyboard
c
        print *, ' ***ENTER 9999 TO LIST HISTOGRAMS'
        print *, ' ***ENTER HISTOGRAM NUMBER TO DISPLAY'
        print *, ' ***ENTER 0 TO GO TO PRINT MENU (EXIT HISTO MENU)'
        read(5,*,ERR=10) hisnum
c
        if (hisnum .ne. 0) then
c
c reset flags
c
          psbutton = .false.
          zoombutton = .false.
c
c send output to graphical window only
c
          call igmeta(0,-111)
c
c call routine which knows how to display each histogram (all the fancy 
c labels etc.)
c
          call hec_online_hisdispl(hisnum,high_ic,run_number,zoomstatus)
c
c display and read buttons if chosen histo is not a control or run 
c summary number
c
          if (abs(hisnum) .lt. 9000 .or. abs(hisnum) .gt. 10000) then
c
c instruct user
c
            print *,'############################################### '
            print *,'Click left mouse button on PS to add histogram',
     +              ' to user summary'
            print *,'############################################### '
            print *,'Click left mouse button on ZOOM to zoom on ', 
     +              'histogram'
            print *,'############################################### '
            print *,'Click right mouse button on histogram to return ',
     +               'to histogram menu' 
            print *,'############################################### '
c
            call hec_online_hisbut(psbutton,zoombutton)
          endif
c
c control over display is now given to HIGZ window and mouse
c as long as user always presses a button, the loop continues.
c right mouse button exits
c
c a zoom will change the current histogram number (hisnum), keep the
c original as hisorg
c
          zoomstatus = .false.
          hisorg = hisnum
          do while (psbutton .or. zoombutton)
c
c if user has chosen zoom button, zoom on displayed plot
c
c zoomed plot has histo id > 1100000
c
            if (zoombutton) then
              hisnum = 9900
              call hec_online_hisdispl(hisnum,high_ic,run_number,
     +                                zoomstatus)
              zoomstatus = .true.
c
c if user has chosen .ps button, put plot directly to ps (no display)
c
            elseif (psbutton) then
              call igmeta(-10,-111)
                call hec_online_hisdispl(hisnum,high_ic,run_number,
     +                                   zoomstatus)                
            endif
c
c
c if either this routine has just zoomed 
c add a comment to the plot
c
            if (zoomstatus) then
              call izitoc(hisorg,chidh)
              comment = 'Zoom on '//chidh
              call hplsof(12.,18.2,comment,0.5,0.,0.,-1.)
            endif
c
c reset display to go only to screen (not .ps)
c
            call igmeta(0,-111)
c
c
c instruct user
c
            print *,'############################################### '
            print *,'Click left mouse button on PS to add histogram',
     +              ' to user summary'
            print *,'############################################### '
            print *,'Click left mouse button on ZOOM to zoom on ', 
     +              'histogram'
            print *,'############################################### '
            print *,'Click right mouse button on histogram to return ',
     +               'to histogram menu' 
            print *,'############################################### '
c
            call hec_online_hisbut(psbutton,zoombutton)
c
          enddo
c
        endif
c
        call igterm
ccc        call igmeta(0,999)
c
c if no error (ie got to here) skip error handling block
c
        goto 11
 10     continue
        print *, ' ***Not a valid histogram number'
        hisnum = -1
 11     continue
c
      enddo
c
c terminate hplot
c
      call hplend
      close(unit=10)
c
c close hbook file
c
      call hrend('hec_online')
      call hdelet(0)
      close(35)
c
      return
      end
